Node-level information used to build cross-block ("double matrix") networks. Each row corresponds to one node and identifies which of the two blocks it belongs to.
Node-level information used to build cross-block ("double matrix") networks. Each row corresponds to one node and identifies which of the two blocks it belongs to.