Two-block node table with pre-computed modularity
Source:R/data.R
double_mat_node_df_with_modularity.RdSame as [double_mat_node_df] with an extra `Module` / modularity column attached so that examples can skip community detection.

R/data.R
double_mat_node_df_with_modularity.RdSame as [double_mat_node_df] with an extra `Module` / modularity column attached so that examples can skip community detection.