Returns the node (vertex) table as a data frame, including attributes such as
name, Modularity, Degree, Strength, etc.
Returns the node (vertex) table as a data frame, including attributes such as
name, Modularity, Degree, Strength, etc.