A small protein-protein interaction (PPI) network used by the `build_graph_from_pie` and STRING-DB examples. The list contains the interaction edge table and a node annotation table.
A small protein-protein interaction (PPI) network used by the `build_graph_from_pie` and STRING-DB examples. The list contains the interaction edge table and a node annotation table.