Tiny helper, used to disambiguate when the magnitude rule below
would otherwise misclassify a small degree value as radians (e.g.
if you actually want 5 degrees, write deg(5)).
Tiny helper, used to disambiguate when the magnitude rule below
would otherwise misclassify a small degree value as radians (e.g.
if you actually want 5 degrees, write deg(5)).