Returns the adjacency matrix of the graph with node names as rownames and colnames. Non-zero entries indicate edges; values correspond to edge weights when the graph is weighted.
Returns the adjacency matrix of the graph with node names as rownames and colnames. Non-zero entries indicate edges; values correspond to edge weights when the graph is weighted.